@@ -34,26 +34,31 @@ def record_input(request):
 
 SAMPLE_RECORDS = [
     (
+        "purelib",
         ("test1.py", "sha256=Y0sCextp4SQtQNU-MSs7SsdxD1W-gfKJtUlEbvZ3i-4", 6),
         b"test1\n",
         True,
     ),
     (
+        "purelib",
         ("test2.py", "sha256=fW_Xd08Nh2JNptzxbQ09EEwxkedx--LznIau1LK_Gg8", 6),
         b"test2\n",
         True,
     ),
     (
+        "purelib",
         ("test3.py", "sha256=qwPDTx7OCCEf4qgDn9ZCQZmz9de1X_E7ETSzZHdsRcU", 6),
         b"test3\n",
         True,
     ),
     (
+        "purelib",
         ("test4.py", "sha256=Y0sCextp4SQtQNU-MSs7SsdxD1W-gfKJtUlEbvZ3i-4", 7),
         b"test1\n",
         False,
     ),
     (
+        "purelib",
         (
             "test5.py",
             "sha256=Y0sCextp4SQtQNU-MSs7SsdxD1W-gfKJtUlEbvZ3i-4",
@@ -62,7 +67,7 @@ SAMPLE_RECORDS = [
         b"test1\n",
         True,
     ),
-    (("test6.py", None, None), b"test1\n", True),
+    ("purelib", ("test6.py", None, None), b"test1\n", True),
 ]
 
 
@@ -100,8 +105,12 @@ class TestRecordEntry:
     def test_valid_elements(self, path, hash_, size):
         RecordEntry.from_elements(path, hash_, size)
 
-    @pytest.mark.parametrize(("elements", "data", "passes_validation"), SAMPLE_RECORDS)
-    def test_populates_attributes_correctly(self, elements, data, passes_validation):
+    @pytest.mark.parametrize(
+        ("scheme", "elements", "data", "passes_validation"), SAMPLE_RECORDS
+    )
+    def test_populates_attributes_correctly(
+        self, scheme, elements, data, passes_validation
+    ):
         path, hash_string, size = elements
 
         record = RecordEntry.from_elements(path, hash_string, size)
@@ -114,19 +123,39 @@ class TestRecordEntry:
             assert record.hash_.name == "sha256"
             assert record.hash_.value == hash_string[len("sha256=") :]
 
-    @pytest.mark.parametrize(("elements", "data", "passes_validation"), SAMPLE_RECORDS)
-    def test_validation(self, elements, data, passes_validation):
+    @pytest.mark.parametrize(
+        ("scheme", "elements", "data", "passes_validation"), SAMPLE_RECORDS
+    )
+    def test_validation(self, scheme, elements, data, passes_validation):
         record = RecordEntry.from_elements(*elements)
         assert record.validate(data) == passes_validation
 
-    @pytest.mark.parametrize(("elements", "data", "passes_validation"), SAMPLE_RECORDS)
-    def test_string_representation(self, elements, data, passes_validation):
+    @pytest.mark.parametrize(
+        ("scheme", "elements", "data", "passes_validation"), SAMPLE_RECORDS
+    )
+    def test_string_representation(self, scheme, elements, data, passes_validation):
         record = RecordEntry.from_elements(*elements)
 
-        expected_string_value = ",".join(
+        expected_row = tuple(
             [(str(elem) if elem is not None else "") for elem in elements]
         )
-        assert str(record) == expected_string_value
+        assert record.to_row() == expected_row
+
+    @pytest.mark.parametrize(
+        ("scheme", "elements", "data", "passes_validation"), SAMPLE_RECORDS
+    )
+    def test_string_representation_with_prefix(
+        self, scheme, elements, data, passes_validation
+    ):
+        record = RecordEntry.from_elements(*elements)
+
+        expected_row = tuple(
+            [
+                (str(elem) if elem is not None else "")
+                for elem in ("prefix/" + elements[0], elements[1], elements[2])
+            ]
+        )
+        assert record.to_row("prefix/") == expected_row
 
     def test_equality(self):
         record = RecordEntry.from_elements(
@@ -199,15 +228,23 @@ class TestParseRecordFile:
     @pytest.mark.parametrize(
         "line, element_count",
         [
-            ("file.py,sha256=AVTFPZpEKzuHr7OvQZmhaU3LvwKz06AJw8mT\\_pNh2yI,3144,", 4),
-            ("distribution-1.0.dist-info/RECORD,,,,", 5),
+            pytest.param(
+                "file.py,sha256=AVTFPZpEKzuHr7OvQZmhaU3LvwKz06AJw8mT\\_pNh2yI,3144,",
+                4,
+                id="four",
+            ),
+            pytest.param(
+                "distribution-1.0.dist-info/RECORD,,,,",
+                5,
+                id="five",
+            ),
         ],
     )
     def test_rejects_wrong_element_count(self, line, element_count):
         with pytest.raises(InvalidRecordEntry) as exc_info:
             list(parse_record_file([line]))
 
-        message = "expected 3 elements, got {}".format(element_count)
+        message = f"expected 3 elements, got {element_count}"
         assert message in str(exc_info.value)
 
     def test_shows_correct_row_number(self):
@@ -221,3 +258,27 @@ class TestParseRecordFile:
             list(parse_record_file(record_lines))
 
         assert "Row Index 3" in str(exc_info.value)
+
+    def test_parse_record_entry_with_comma(self):
+        record_lines = [
+            '"file1,file2.txt",sha256=AVTFPZpEKzuHr7OvQZmhaU3LvwKz06AJw8mT\\_pNh2yI,3144',
+            "distribution-1.0.dist-info/RECORD,,",
+        ]
+        records = list(parse_record_file(record_lines))
+        assert records == [
+            (
+                "file1,file2.txt",
+                "sha256=AVTFPZpEKzuHr7OvQZmhaU3LvwKz06AJw8mT\\_pNh2yI",
+                "3144",
+            ),
+            ("distribution-1.0.dist-info/RECORD", "", ""),
+        ]
+
+    def test_parse_record_entry_with_backslash_path(self):
+        record_lines = [
+            "distribution-1.0.dist-info\\RECORD,,",
+        ]
+        records = list(parse_record_file(record_lines))
+        assert records == [
+            ("distribution-1.0.dist-info/RECORD", "", ""),
+        ]
